@@ -5,8 +5,8 @@ from feii.cli import RolloverCLI
 
 @click.command(
   cls=RolloverCLI,
-  short_help='Rollover the big indexes.',
+  short_help='Rollover the indexes.',
   epilog="Run 'feii rollover COMMAND --help' for more information on a command."
 )
 def cli():
-  """Rollover the big indexes"""
+  """Rollover the indexes"""
