@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-import os
+# import os
 from configparser import ConfigParser
 from feii.config import Config
 
@@ -21,7 +21,3 @@ class PathToFile(Config):
     if "CONFIG" in self.t1:
       for one, test in self.t1["CONFIG"].items():
         print("Name [{0}] - [{1}]".format( one, test ))
-
-if __name__ == "__main__":
-
-  class_path_to_file = PathToFile()
